#
# spec file for package python-fuse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-fuse
Version:        1.0.8
Release:        1.3
Summary:        Python bindings for FUSE
License:        LGPL-2.1-only
URL:            https://github.com/libfuse/python-fuse
Source:         https://github.com/libfuse/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  fuse-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Python bindings for FUSE (User space File System)

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Can not figured how to do it.

%files %{python_files}
%license COPYING
%doc README.* FAQ AUTHORS
%{python_sitearch}/fuse.py
%pycache_only %{python_sitearch}/__pycache__/fuse*.py*
%{python_sitearch}/fuseparts
%{python_sitearch}/fuse_python-%{version}.dist-info

%changelog
* Wed Sep  4 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- update to 1.0.8:
  * Add README.cups.md
  * Do not unilaterally import distutils in setup.py
  * Add support for objects that support buffer protocol for "read" calls
  * Remove trailing space on files
  * CI: Add workflow to build Python wheels
  * Fix setup.py uninitialized variables issue
  * Build sdist in CI
  * Add cp310 wheel to CI
  * CI: Add workaround for broken py 3.5 in GitHub Actions.
- dropped patch: no-more-distutils.patch - no longer needed.
* Tue Jan 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch no-more-distutils.patch:
  * Stop using distutils unilaterally.
- Switch to autosetup and pyproject macros.
- Be more clear about files in %%files.
* Mon Dec  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.7:
  * Suppress SyntaxWarnings in python3.12
  * Doc: Minor spelling fixes
- update to 1.0.6:
  * Python 3.12 compatibility.
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to v1.0.5:
  * Fix issue with python 3.10
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Improve path handling for Python >= 3.6
  * fix race in xmp.py
  * fix surrogateescape handling in fsyncdir/readdir/write
  * unbreak xmp.py for python2
  * fix object leak in open_func()
  * fix temporary objects leak
* Sat Dec  5 2020 andy great <andythe_great@pm.me>
- Update to version 1.0.0.
  * Add poll support.
  * Use bytes objects for read and write data: please note that
    while this has no effect on Python 2,it is a breaking change in
    Python 3; it's worth it however since it fixes a serious
    usability bug that arbitrarily limited file content to valid
    UTF-8 data.
* Wed Jun 20 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue Jan 31 2012 saschpe@suse.de
- Fix SLE_11 build
* Fri Jan 27 2012 Greg.Freemyer@gmail.com
- upgrade to version 0.2.1
  * make_release.sh:
    Fix generation of MANIFEST.in in make_release.sh
  * fuse.py, fuseparts/__init__.py:
    Fix previous fix for ctors of Timespec and Flock to be backwards
    compatible, bump version to 0.2.1
  * fuseparts/_fusemodule.c:
    Fix incorrect handling of getxattr for the size=0 case
  * fuse.py:
    absolutify the mount path when "fetch_mp" is set
* Fri Jun 27 2008 prusnak@suse.cz
- created package (v 0.2)
  python-fuse provides python bindings to the fuse library (fuse = userspace filesystem)
